clear all
set more off

*-------------------------------------
* combine data and create weekly panel
use data/td_data, clear

* gc ff spread
gen gc_ff=dff-on

merge 1:1 td using data/td, nogen
sort td

* drop saturdays and sundays
gen dow=dow(td)
drop if dow==0 | dow==6

gen carry=_n
replace carry=. if dow!=3
carryforward carry, replace


* Take the max of td which makes it a Tuesday, want to match to the fails data reported on Wednesday
collapse (max) td (mean) gc* vix gb* aaa_tr , by(carry)

format vix %5.2fc
format gc* %5.3fc

replace td=td+1
merge 1:1 td using data/fails, nogen

sort td
gen n=_n
drop carry
order n, first


* gap
foreach var in treasury mbs agency {
gen `var'_g=`var'_r-`var'_d
}

label variable treasury_d "Treasury Deliver"
label variable treasury_r "Treasury Receive"

label variable agency_d "Agency Deliver"
label variable agency_r "Agency Receive"


* tidy up
format *_d *_r *_g %15.0fc

drop if td<td(01aug2001)
drop if td>td(31jul2020)
tsset n

save data/fails_gc, replace



*--------------------------------
* Set up data for main regressions
use data/fails_gc, clear

rename treasury_* tr_*
foreach var in tr mbs agency {

* scale amounts
replace `var'_r=`var'_r/1000
replace `var'_d=`var'_d/1000  
replace `var'_g=`var'_g/1000  

* totals
gen `var'_t=`var'_d+`var'_r

foreach type in r d t g {
gen d_`var'_`type'=d.`var'_`type'
}

gen d_`var'_abs=abs(d.`var'_r-d.`var'_d)
}


* first differences
gen d_vix=d.vix
gen d_gc1=d.gc_tr1

label variable d_vix "$\Delta$ VIX"
label variable d_gc1 "GC Repo-1m T-bill"


* combined categories
gen d_tr_agency_r=d_tr_r+d_agency_r
gen d_tr_agency_mbs_r=d_tr_r+d_agency_r+d_mbs_r
gen d_tr_agency_d=d_tr_d+d_agency_d

* create and label cross terms
gen crisis=0
replace crisis=1 if year(td)==2008
replace crisis=1 if year(td)==2009
gen cross=crisis*d_gc1

label variable d_gc1 "$\Delta$ GC Repo-1m T-Bill"
label variable crisis "Crisis"
label variable cross "$\Delta$ GC Repo-1m T-Bill x Crisis"


gen covid=0
replace covid=1 if td>td(10mar2020)
gen cross_covid=covid*d_gc1

label variable covid "Covid"
label variable cross_covid "$\Delta$ GC Repo-1m T-Bill x Covid"

save data/regs, replace