clear all
set more off


*-----------------------------------
* FIGURE 2 Treasury and Agency Fails
use data/fails_gc, clear

format td %tdnn/CCYY
local td1=td(1jan2008)
local td2=td(1jan2010)
local td3=td(1jan2015)
local options xtitle("", size(small)) xline(`td1' `td2' `td3')

* show on log scale
twoway (line treasury_r td, yscale(log) ylabel(10000 50000 100000 250000 500000 1000000 2000000)) (line treasury_d td, yscale(log)), `options' title("Panel A. Treasury Fails") name("Treasury_log") 
graph export graphs/fails_tr_log.eps, replace

twoway (line agency_r td, yscale(log) ylabel(1000 10000 100000)) (line agency_d td, yscale(log)), `options' title("Panel B. Agency Fails") name("Agency_log")
graph export graphs/fails_agency_log.eps, replace




*--------------------------------
* FIGURE 3 GC-Repo spread and vol
use data/td_data, clear

drop if year(td)<2009
asrol gc_tr1, window(td 365) stat(sd) gen(sd) min(220)

drop if year(td)<2010
gen pre=(year(td)<2015)
egen mean=mean(gc_tr1), by(pre)
label variable mean "Mean pre- and post-LCR"

format td %tdCCYY
label variable gc_tr1 "GC-Tr 1m spread"
label variable sd "GC-Tr 1m Vol"
local cutoff=td(1jan2015)
twoway (line gc_tr1 td, xline(`cutoff')) (line mean td) (line sd td, yaxis(2)), xtitle("") legend(cols(1))

graph export graphs/gc_repo_vol.eps, replace



*--------------------------------------------
* FIGURE 4 Treasury fails during the pandemic
use data/fails_gc, clear

drop if year(td)<2020
local pandemic=td(11mar2020)

gen treasury_total=(treasury_d+treasury_r)/1000
format treasury_total %5.0fc
label var treasury_total "Total Treasury Fails"

format gc_tr1 %5.2fc
label var gc_tr1 "GC Repo - Tr 1m"
format td %tdnn/CCYY

twoway (line treasury_total td, xline(`pandemic')) (line gc_tr1 td, yaxis(2)), xtitle("")
graph export graphs/covid_fails.pdf, replace





*--------------------------------------------------------------
* FIGURE 1 Safe asset share from Gorton, Lewellen, Metrick 2012
import excel raw/other_data.xlsx, sheet("FoF") firstrow case(lower) clear


gen tq=quarterly(quarter, "YQ")
format tq %tq
order tq, first

keep tq deposits moneylike mbsabs corporate other

foreach var of varlist deposits-other {
rename `var' q_`var'
}

reshape long q_, i(tq) j(cat) string

egen total=sum(q_), by(tq)
gen s_=q_/total
drop q

reshape wide s_, i(tq) j(cat) string


gen zero=0
gen a_deposits=zero+s_deposits
gen a_moneylike=a_deposits+s_moneylike
gen a_mbsabs=a_moneylike+s_mbsabs
gen a_corporate=a_mbsabs+s_corporate
gen a_other=a_corporate+s_other

local tq1=tq(1952q1)
local tq2=tq(2012q1)

format tq %tqCCYY
twoway (rarea zero a_deposits tq, fcolor(%100)) (rarea a_deposits a_moneylike tq, fcolor(%90)) ///
(rarea a_moneylike a_mbsabs tq, fcolor(%70)) (rarea a_mbsabs a_corporate tq, fcolor(%50)) ///
(rarea a_corporate a_other tq, color(ltblue) fcolor(%30)), ///
legend(order(1 "Deposits" 2 "Money-like Debt" 3 "MBS/ABS Debt" 4 "Corporate Bonds and Loans" 5 "Other Liabilities")) ///
xtitle("") ytitle("Share") xlabel(`tq1'(40)`tq2')
graph export graphs/safe_share.pdf, replace



*------------------------------------------
* FIGURE 5 Profit series natural and in log
import excel raw/other_data.xlsx, sheet("profit_monthly") firstrow clear

gen tm=ym(Year, Month)
format tm %tmCCYY

twoway  (area Recession tm, yaxis(2) color(gs14) lwidth(none)) (line Profit tm, color(navy)), ///
ytitle("", axis(2)) ylabel("", axis(2)) ytitle("") title("Panel A. Profit.")
graph export graphs/profit_natural.eps, replace

 
twoway  (area Recession tm, yaxis(2) color(gs14) lwidth(none)) (line Profit tm, color(navy) yscale(log)), ///
ytitle("", axis(2)) ylabel("", axis(2)) ytitle("") ylabel(1 10 100 1000) title("Panel B. Profit on Log Scale.")
graph export graphs/profit_log.eps, replace



*---------------------------------
* U.S. Debt to GDP for next figure
import excel raw/other_data.xlsx, sheet("US_debt") cellrange(A16:K239) firstrow  clear

rename A year
keep year debtGDP
drop if year==.
save data/debt_gdp, replace


*-----------------------------------
* FIGURE 6A Treasuries Held to Back
clear all
import excel raw/other_data, sheet("fraction_held") firstrow case(lower) clear

destring fractionheld, replace force
replace fractionheld=100*fractionheld

gen td1=date(observation, "YMD") 
gen td2=date(observation, "DMY") 

gen td=td1
replace td=td2 if td1==.
format td %tdCCYY

gen year=year(td)
replace year=. if month(td)!=1
merge m:1 year using data/debt_gdp, keepusing(debtGDP) keep(master matched) nogen
sort td


label variable fractionheld "Fraction Held to Back Notes"

twoway (line fractionheld td) (line debtGDP td), ///
ytitle("%") ylabel(0(5)30) xtitle("") title("Panel A. Treasuries Held to Back Notes as a Percentage of Total U.S. Debt." "U.S. Debt to GDP Ratio.") name("one")
graph export graphs/treasuries_held_back.eps, replace



*-----------------------------------------------------------
* FIGURE 6B  Ratio of US Bonds on Hand to Loans and Discounts
import excel raw/other_data.xlsx, sheet("on_hand") firstrow case(lower) clear

gen td=date(date, "MDY")
format td %tdCCYY

replace ratiotbld=ratiotbld*100
format ratiotbld %5.0fc

twoway (line ratiotbld td), ///
ytitle("%") xtitle("") title("Panel B. Ratio of U.S. Bonds on Hand to Loans and Discounts.") name("two")
graph export graphs/bonds_on_hand.eps, replace





 
*---------------------------------
* FIGURE 7 Notes to Deposits Ratio
import excel raw/other_data.xlsx, sheet("Notes to DD") firstrow clear
drop if year==.

twoway (line notesdeposits year) (line debtgdp year, yaxis(2)), ///
legend(order(1 "Ratio Notes/Deposits" 2 "Debt/GDP" )) ///
ytitle("Notes/Deposits %") ylabel(0(10)60) ytitle("Debt/GDP %", axis(2)) xtitle("") xlabel(#10)
graph export graphs/deposits_to_notes.eps, replace