clear all
set more off

noisily: di _newline(200)



*local stars starl(* .05 ** .01)



*--------
* TABLE 7

foreach lhs in profit ln_profit {

* use quarterly data for muni spread regression
use data/profit_quarter, clear
est drop _all
eststo: ivreg2 `lhs' spread, bw(41) robust


* other regs from annual data
use data/profit_year, clear

eststo: ivreg2 `lhs' ln_dgdp, bw(11) robust
eststo: ivreg2 `lhs' ln_avail_dgdp, bw(11) robust
eststo: ivreg2 `lhs' ln_avail_dgdp spread, bw(11) robust

* from the last specification generate errors
predict err, residuals

* find AR(1) coefficient
corr err l.err
local rho=`r(rho)'

* generate transformed y and x variables
foreach var in `lhs' ln_avail_dgdp spread {
rename `var' orig_`var'
gen `var'=orig_`var'-`rho'*l.orig_`var'
}

eststo: ivreg2 `lhs' ln_avail_dgdp spread, bw(11) robust
use data/profit_year, clear


* output table
noisily: esttab est2 est3 est1 est4 est5, ar2 nocons label `stars'
esttab est2 est3 est1 est4 est5 using tex/`lhs'.tex, nocons ///
ar2 label replace booktabs ///
mgroups("OLS" "GLS", pattern(1 0 0 0 1) prefix(\multicolumn{@span}{c}{) ///
suffix(}) span erepeat(\cmidrule(lr){@span})) nomtitles `stars'
}



*------------------
* APPENDIX TABLE 10

* Annual data
use data/profit_year, clear

* cutoff terms
gen cutoff=(year>1900)
gen cross_ln_avail_dgdp=cutoff*ln_avail_dgdp

est drop _all
eststo: ivreg2 profit ln_avail_dgdp cross_ln_avail_dgdp cutoff, bw(11) robust
eststo: ivreg2 ln_profit ln_avail_dgdp cross_ln_avail_dgdp cutoff, bw(11) robust



* quarterly data
use data/profit_quarter, clear


*gen cutoff=(year(dofq(tq))>1900)
gen cutoff=(tq>tq(1900q4))
gen cross_spread=cutoff*spread
label variable cross_spread "Muni Spread x (t$>$1900)"

* create fake variables so Stata knows how to label variables in the combined table
gen cross_ln_avail_dgdp=.
gen ln_avail_dgdp=.
label variable ln_avail_dgdp "ln(Avail/GDP)"
label variable cross_ln "ln(Avail/GDP) x (t$>$1900)"


eststo: ivreg2 profit spread cross_spread cutoff, bw(41) robust
eststo: ivreg2 ln_profit spread cross_spread cutoff, bw(41) robust


noisily: esttab est1 est3 est2 est4, label  r2
esttab est1 est3 est2 est4 using tex/profit_1900.tex, drop(cutoff _cons) ///
ar2 label replace booktabs ///
mgroups("profit" "ln(profit)", pattern(1 0 1 0) prefix(\multicolumn{@span}{c}{) ///
suffix(}) span erepeat(\cmidrule(lr){@span})) nomtitles `stars'
